@@ -202,7 +202,10 @@ usage(FILE *out, const char *name)
           " -H, --line-height     defines the height to make each menu line (0 = default height). (wx)\n"
           " -M, --margin          defines the empty space on either side of the menu. (wx)\n"
           " -W, --width-factor    defines the relative width factor of the menu (from 0 to 1). (wx)\n"
+          " -B, --border          defines the width of the border in pixels around the menu. (wx)\n"
           " --ch                  defines the height of the cursor (0 = scales with line height). (wx)\n"
+          " --cw                  defines the width of the cursor. (wx)\n"
+          " --hp                  defines the horizontal padding for the entries in single line mode. (wx)\n"
           " --fn                  defines the font to be used ('name [size]'). (wx)\n"
           " --tb                  defines the title background color. (wx)\n"
           " --tf                  defines the title foreground color. (wx)\n"
@@ -216,8 +219,11 @@ usage(FILE *out, const char *name)
           " --fbf                 defines the feedback foreground color. (wx)\n"
           " --sb                  defines the selected background color. (wx)\n"
           " --sf                  defines the selected foreground color. (wx)\n"
+          " --ab                  defines the alternating background color. (wx)\n"
+          " --af                  defines the alternating foreground color. (wx)\n"
           " --scb                 defines the scrollbar background color. (wx)\n"
-          " --scf                 defines the scrollbar foreground color. (wx)\n", out);
+          " --scf                 defines the scrollbar foreground color. (wx)\n"
+          " --bdr                 defines the border color. (wx)\n", out);
 
     exit((out == stderr ? EXIT_FAILURE : EXIT_SUCCESS));
 }
@@ -270,12 +276,17 @@ do_getopt(struct client *client, int *argc, char **argv[])
         { "line-height",  required_argument, 0, 'H' },
         { "margin",       required_argument, 0, 'M' },
         { "width-factor", required_argument, 0, 'W' },
-        { "ch",           required_argument, 0, 0x118 },
+        { "border",       required_argument, 0, 'B' },
+        { "ch",           required_argument, 0, 0x120 },
+        { "cw",           required_argument, 0, 0x125 },
+        { "hp",           required_argument, 0, 0x122 },
         { "fn",           required_argument, 0, 0x101 },
         { "tb",           required_argument, 0, 0x102 },
         { "tf",           required_argument, 0, 0x103 },
         { "fb",           required_argument, 0, 0x104 },
         { "ff",           required_argument, 0, 0x105 },
+        { "cb",           required_argument, 0, 0x126 },
+        { "cf",           required_argument, 0, 0x127 },
         { "nb",           required_argument, 0, 0x106 },
         { "nf",           required_argument, 0, 0x107 },
         { "hb",           required_argument, 0, 0x108 },
@@ -284,8 +295,11 @@ do_getopt(struct client *client, int *argc, char **argv[])
         { "fbf",          required_argument, 0, 0x111 },
         { "sb",           required_argument, 0, 0x112 },
         { "sf",           required_argument, 0, 0x113 },
+        { "ab",           required_argument, 0, 0x123 },
+        { "af",           required_argument, 0, 0x124 },
         { "scb",          required_argument, 0, 0x114 },
         { "scf",          required_argument, 0, 0x115 },
+        { "bdr",          required_argument, 0, 0x121 },
 
         { "disco",       no_argument,       0, 0x116 },
         { 0, 0, 0, 0 }
@@ -301,7 +315,7 @@ do_getopt(struct client *client, int *argc, char **argv[])
     for (optind = 0;;) {
         int32_t opt;
 
-        if ((opt = getopt_long(*argc, *argv, "hviwxcl:I:p:P:I:bfm:H:M:W:ns", opts, NULL)) < 0)
+        if ((opt = getopt_long(*argc, *argv, "hviwxcl:I:p:P:I:bfm:H:M:W:B:ns", opts, NULL)) < 0)
             break;
 
         switch (opt) {
@@ -377,9 +391,18 @@ do_getopt(struct client *client, int *argc, char **argv[])
             case 'W':
                 client->width_factor = strtof(optarg, NULL);
                 break;
+            case 'B':
+                client->border_size = strtol(optarg, NULL, 10);
+                break;
             case 0x120:
                 client->cursor_height = strtol(optarg, NULL, 10);
                 break;
+            case 0x125:
+                client->cursor_width = strtol(optarg, NULL, 10);
+                break;
+            case 0x122:
+                client->hpadding = strtol(optarg, NULL, 10);
+                break;
             case 0x101:
                 client->font = optarg;
                 break;
@@ -395,6 +418,12 @@ do_getopt(struct client *client, int *argc, char **argv[])
             case 0x105:
                 client->colors[BM_COLOR_FILTER_FG] = optarg;
                 break;
+            case 0x126:
+                client->colors[BM_COLOR_CURSOR_BG] = optarg;
+                break;
+            case 0x127:
+                client->colors[BM_COLOR_CURSOR_FG] = optarg;
+                break;
             case 0x106:
                 client->colors[BM_COLOR_ITEM_BG] = optarg;
                 break;
@@ -419,12 +448,21 @@ do_getopt(struct client *client, int *argc, char **argv[])
             case 0x113:
                 client->colors[BM_COLOR_SELECTED_FG] = optarg;
                 break;
+            case 0x123:
+                client->colors[BM_COLOR_ALTERNATE_BG] = optarg;
+                break;
+            case 0x124:
+                client->colors[BM_COLOR_ALTERNATE_FG] = optarg;
+                break;
             case 0x114:
                 client->colors[BM_COLOR_SCROLLBAR_BG] = optarg;
                 break;
             case 0x115:
                 client->colors[BM_COLOR_SCROLLBAR_FG] = optarg;
                 break;
+            case 0x121:
+                client->colors[BM_COLOR_BORDER] = optarg;
+                break;
 
             case 0x116:
                 disco();
@@ -465,6 +503,8 @@ menu_with_options(struct client *client)
     bm_menu_set_font(menu, client->font);
     bm_menu_set_line_height(menu, client->line_height);
     bm_menu_set_cursor_height(menu, client->cursor_height);
+    bm_menu_set_cursor_width(menu, client->cursor_width);
+    bm_menu_set_hpadding(menu, client->hpadding);
     bm_menu_set_title(menu, client->title);
     bm_menu_set_prefix(menu, client->prefix);
     bm_menu_set_filter_mode(menu, client->filter_mode);
@@ -477,6 +517,7 @@ menu_with_options(struct client *client)
     bm_menu_set_spacing(menu, !client->no_spacing);
     bm_menu_set_password(menu, client->password);
     bm_menu_set_width(menu, client->hmargin_size, client->width_factor);
+    bm_menu_set_border_size(menu, client->border_size);
 
     if (client->center) {
         bm_menu_set_align(menu, BM_ALIGN_CENTER);
