@@ -14,10 +14,13 @@ struct client {
     const char *initial_filter;
     uint32_t line_height;
     uint32_t cursor_height;
+    uint32_t cursor_width;
+    uint32_t hpadding;
     uint32_t lines;
     uint32_t selected;
     uint32_t monitor;
     uint32_t hmargin_size;
+    uint32_t border_size;
     float width_factor;
     bool bottom;
     bool center;
