@@ -19,6 +19,8 @@ static const char *default_colors[BM_COLOR_LAST] = {
     "#D81860FF", // BM_COLOR_TITLE_FG
     "#121212FF", // BM_COLOR_FILTER_BG
     "#CACACAFF", // BM_COLOR_FILTER_FG
+    "#121212FF", // BM_COLOR_CURSOR_BG
+    "#CACACAFF", // BM_COLOR_CURSOR_FG
     "#121212FF", // BM_COLOR_ITEM_BG
     "#CACACAFF", // BM_COLOR_ITEM_FG
     "#121212FF", // BM_COLOR_HIGHLIGHTED_BG
@@ -27,8 +29,11 @@ static const char *default_colors[BM_COLOR_LAST] = {
     "#121212FF", // BM_COLOR_FEEDBACK_FG
     "#121212FF", // BM_COLOR_SELECTED_BG
     "#D81860FF", // BM_COLOR_SELECTED_FG
+    "#121212FF", // BM_COLOR_ALTERNATE_BG
+    "#CACACAFF", // BM_COLOR_ALTERNATE_FG
     "#121212FF", // BM_COLOR_SCROLLBAR_BG
     "#D81860FF", // BM_COLOR_SCROLLBAR_FG
+    "#D81860FF", // BM_COLOR_BORDER
 };
 
 /**
@@ -174,10 +179,14 @@ bm_menu_set_filter(struct bm_menu *menu, const char *filter)
 {
     assert(menu);
 
+    if (strcmp(menu->filter ? menu->filter : "", filter ? filter : ""))
+        menu->dirty = true;
+
     free(menu->filter);
     menu->filter_size = (filter ? strlen(filter) : 0);
     menu->filter = (menu->filter_size > 0 ? bm_strdup(filter) : NULL);
     menu->curses_cursor = (menu->filter ? bm_utf8_string_screen_width(menu->filter) : 0);
+    menu->dirty |= (menu->cursor != menu->filter_size);
     menu->cursor = menu->filter_size;
 }
 
@@ -303,6 +312,48 @@ bm_menu_get_cursor_height(struct bm_menu *menu)
     return menu->cursor_height;
 }
 
+void
+bm_menu_set_cursor_width(struct bm_menu *menu, uint32_t cursor_width)
+{
+    assert(menu);
+    menu->cursor_width = cursor_width;
+}
+
+uint32_t
+bm_menu_get_cursor_width(struct bm_menu *menu)
+{
+    assert(menu);
+    return menu->cursor_width;
+}
+
+void
+bm_menu_set_hpadding(struct bm_menu *menu, uint32_t hpadding)
+{
+    assert(menu);
+    menu->hpadding = hpadding;
+}
+
+uint32_t
+bm_menu_get_hpadding(struct bm_menu *menu)
+{
+    assert(menu);
+    return menu->hpadding;
+}
+
+void
+bm_menu_set_border_size(struct bm_menu* menu, uint32_t border_size)
+{
+    assert(menu);
+    menu->border_size = border_size;
+}
+
+uint32_t
+bm_menu_get_border_size(struct bm_menu* menu)
+{
+    assert(menu);
+    return menu->border_size;
+}
+
 uint32_t
 bm_menu_get_height(struct bm_menu *menu)
 {
@@ -1141,7 +1192,7 @@ bm_menu_run_with_pointer(struct bm_menu *menu, struct bm_pointer pointer)
         }
     }
 
-    if (pointer.event_mask & POINTER_EVENT_MOTION) {
+    if (pointer.event_mask & (POINTER_EVENT_ENTER | POINTER_EVENT_MOTION)) {
         menu_point_select(menu, pointer.pos_x, pointer.pos_y, displayed);
     }
 
